@@ -1,6 +1,4 @@
 /***************************************************************************
- *   ktlisttasks.cpp                                                       *
- *   --------------------------------------------------------------------  *
  *   KT list view item tasks implementation.                               *
  *   --------------------------------------------------------------------  *
  *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
@@ -73,7 +71,7 @@ void KTListTasks::print (KTPrint& printer) const
   stnd = printer.getFont();
 
   printer.setFont(QFont( KGlobalSettings::generalFont().family(), 10, QFont::Bold ));
-  printer.print (i18n("Task Name:"), 1, KTPrint::alignTextLeft);
+  printer.print (i18n("Task name:"), 1, KTPrint::alignTextLeft);
   printer.print (i18n("Program:"), 2, KTPrint::alignTextCenter);
   printer.print (i18n("Description:"),3,KTPrint::alignTextRight);
 
