@@ -1,6 +1,4 @@
 /***************************************************************************
- *   ktview.h                                                              *
- *   --------------------------------------------------------------------  *
  *   KT main view header.                                                  *
  *   --------------------------------------------------------------------  *
  *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
@@ -100,6 +98,35 @@ public:
   */
   void run() const;
 
+/**
+  * Disable selected icons
+  */
+  void disableIcons();
+
+signals:
+
+/** Enables/disables modification 
+  * buttons depending
+  * on if a task is selected
+  */
+  void enableModificationButtons(bool);
+
+/** Enables/disables paste button depending
+  * on clipboard contents
+  */
+  void enablePaste(bool);
+
+/** Enables/disables "Run now" depending
+  * on the task settings
+  */
+  void enableRunNow(bool);
+
+/** Enables/disables "Activated" setting
+  * on the menu depending on the task
+  * configuration
+  */
+  void enableEnabled(bool);
+
 public slots:
 
 /**
