@@ -31,7 +31,7 @@
 #include "BackupProfile.h"
 #include "BackupProfileManager.h"
 #include "ImageCache.h"
-#include "KDat.h"
+#include "KDatMainWindow.h"
 #include "Node.h"
 #include "Range.h"
 #include "Tape.h"
@@ -129,7 +129,7 @@ void Node::collapsed()
 
 void Node::selected()
 {
-    KDat::getInstance()->hideInfo();
+    KDatMainWindow::getInstance()->hideInfo();
 }
 
 void Node::popupMenu( const QPoint& )
@@ -223,12 +223,12 @@ void TapeNode::expanding( bool expand )
 
 void TapeNode::selected()
 {
-    KDat::getInstance()->showTapeInfo( _tape );
+    KDatMainWindow::getInstance()->showTapeInfo( _tape );
 }
 
 void TapeNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupTapeMenu( p );
+    KDatMainWindow::getInstance()->popupTapeMenu( p );
 }
 
 ArchiveNode* TapeNode::findArchiveNode( Archive* archive )
@@ -296,12 +296,12 @@ void ArchiveNode::expanding( bool expand )
 
 void ArchiveNode::selected()
 {
-    KDat::getInstance()->showArchiveInfo( _archive );
+    KDatMainWindow::getInstance()->showArchiveInfo( _archive );
 }
 
 void ArchiveNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupArchiveMenu( p );
+    KDatMainWindow::getInstance()->popupArchiveMenu( p );
 }
 
 TapeDirectoryNode::TapeDirectoryNode( File* file )
@@ -364,7 +364,7 @@ void TapeDirectoryNode::collapsed()
 
 void TapeDirectoryNode::selected()
 {
-    KDat::getInstance()->showTapeFileInfo( _file );
+    KDatMainWindow::getInstance()->showTapeFileInfo( _file );
 }
 
 TapeFileNode::TapeFileNode( File* file )
@@ -396,7 +396,7 @@ bool TapeFileNode::isType( int type )
 
 void TapeFileNode::selected()
 {
-    KDat::getInstance()->showTapeFileInfo( _file );
+    KDatMainWindow::getInstance()->showTapeFileInfo( _file );
 }
 
 SelectableNode::SelectableNode( int type, const QString & text, const QPixmap& pixmap, int state )
@@ -607,7 +607,7 @@ void SelectableNode::setSelected( bool select )
 
     owner->repaint();
 
-    KDat::getInstance()->configureUI( TapeManager::instance()->getMountedTape() );
+    KDatMainWindow::getInstance()->configureUI( TapeManager::instance()->getMountedTape() );
 }
 
 RangeableNode::RangeableNode( int type, const QString & text, const QPixmap& pixmap, int state )
@@ -696,12 +696,12 @@ void MountedArchiveNode::expanding( bool expand )
 
 void MountedArchiveNode::selected()
 {
-    KDat::getInstance()->showArchiveInfo( _archive );
+    KDatMainWindow::getInstance()->showArchiveInfo( _archive );
 }
 
 void MountedArchiveNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupMountedArchiveMenu( p );
+    KDatMainWindow::getInstance()->popupMountedArchiveMenu( p );
 }
 
 MountedTapeDirectoryNode::MountedTapeDirectoryNode( File* file, int state )
@@ -806,12 +806,12 @@ void MountedTapeDirectoryNode::collapsed()
 
 void MountedTapeDirectoryNode::selected()
 {
-    KDat::getInstance()->showTapeFileInfo( _file );
+    KDatMainWindow::getInstance()->showTapeFileInfo( _file );
 }
 
 void MountedTapeDirectoryNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupMountedTapeFileMenu( p );
+    KDatMainWindow::getInstance()->popupMountedTapeFileMenu( p );
 }
 
 MountedTapeFileNode::MountedTapeFileNode( File* file, int state )
@@ -883,12 +883,12 @@ bool MountedTapeFileNode::isType( int type )
 
 void MountedTapeFileNode::selected()
 {
-    KDat::getInstance()->showTapeFileInfo( _file );
+    KDatMainWindow::getInstance()->showTapeFileInfo( _file );
 }
 
 void MountedTapeFileNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupMountedTapeFileMenu( p );
+    KDatMainWindow::getInstance()->popupMountedTapeFileMenu( p );
 }
 
 ArchiveableNode::ArchiveableNode( int type, const QString & text, const QPixmap& pixmap, int state )
@@ -1004,12 +1004,12 @@ void RootNode::collapsed()
 
 void RootNode::selected()
 {
-    KDat::getInstance()->showFileInfo( "/" );
+    KDatMainWindow::getInstance()->showFileInfo( "/" );
 }
 
 void RootNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupLocalFileMenu( p );
+    KDatMainWindow::getInstance()->popupLocalFileMenu( p );
 }
 
 DirectoryNode::DirectoryNode( const QString & text, int state )
@@ -1130,12 +1130,12 @@ void DirectoryNode::selected()
     path.prepend( "/" );
     path = path.left( path.length() - 1 );
 
-    KDat::getInstance()->showFileInfo( path );
+    KDatMainWindow::getInstance()->showFileInfo( path );
 }
 
 void DirectoryNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupLocalFileMenu( p );
+    KDatMainWindow::getInstance()->popupLocalFileMenu( p );
 }
 
 FileNode::FileNode( const QString & text, int state )
@@ -1173,12 +1173,12 @@ void FileNode::selected()
     path.prepend( "/" );
     path = path.left( path.length() - 1 );
 
-    KDat::getInstance()->showFileInfo( path );
+    KDatMainWindow::getInstance()->showFileInfo( path );
 }
 
 void FileNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupLocalFileMenu( p );
+    KDatMainWindow::getInstance()->popupLocalFileMenu( p );
 }
 
 TapeDriveNode::TapeDriveNode()
@@ -1223,15 +1223,15 @@ void TapeDriveNode::expanding( bool expand )
 void TapeDriveNode::selected()
 {
     if ( TapeManager::instance()->getMountedTape() ) {
-        KDat::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
+        KDatMainWindow::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
     } else {
-        KDat::getInstance()->hideInfo();
+        KDatMainWindow::getInstance()->hideInfo();
     }
 }
 
 void TapeDriveNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupTapeDriveMenu( p );
+    KDatMainWindow::getInstance()->popupTapeDriveMenu( p );
 }
 
 void TapeDriveNode::slotTapeMounted()
@@ -1240,7 +1240,7 @@ void TapeDriveNode::slotTapeMounted()
     setText( TapeManager::instance()->getMountedTape()->getName() );
 
     if ( this == owner->getCurrentItem() ) {
-        KDat::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
+        KDatMainWindow::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
     }
 
     if ( isExpanded() ) {
@@ -1262,7 +1262,7 @@ void TapeDriveNode::slotTapeUnmounted()
     }
 
     if ( this == owner->getCurrentItem() ) {
-        KDat::getInstance()->hideInfo();
+        KDatMainWindow::getInstance()->hideInfo();
     }
 }
 
@@ -1275,7 +1275,7 @@ void TapeDriveNode::slotTapeModified( Tape* tape )
     setText( tape->getName() );
 
     if ( owner->getCurrentItem() == this ) {
-        KDat::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
+        KDatMainWindow::getInstance()->showTapeInfo( TapeManager::instance()->getMountedTape() );
     }
 
     if ( ( childCount() == 0 ) && ( !isExpanded() ) ) {
@@ -1458,12 +1458,12 @@ bool BackupProfileNode::isType( int type )
 
 void BackupProfileNode::selected()
 {
-    KDat::getInstance()->showBackupProfileInfo( _backupProfile );
+    KDatMainWindow::getInstance()->showBackupProfileInfo( _backupProfile );
 }
 
 void BackupProfileNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupBackupProfileMenu( p );
+    KDatMainWindow::getInstance()->popupBackupProfileMenu( p );
 }
 
 BackupProfileRootNode::BackupProfileRootNode()
@@ -1492,7 +1492,7 @@ void BackupProfileRootNode::setSelected( BackupProfile* pBackupProfile )
         pNode->selected();
     }
 
-    KDat::getInstance()->configureUI( TapeManager::instance()->getMountedTape() );
+    KDatMainWindow::getInstance()->configureUI( TapeManager::instance()->getMountedTape() );
 }
 
 bool BackupProfileRootNode::isType( int type )
@@ -1534,7 +1534,7 @@ void BackupProfileRootNode::collapsed()
 
 void BackupProfileRootNode::popupMenu( const QPoint& p )
 {
-    KDat::getInstance()->popupBackupProfileRootMenu( p );
+    KDatMainWindow::getInstance()->popupBackupProfileRootMenu( p );
 }
 
 void BackupProfileRootNode::slotBackupProfileAdded( BackupProfile* backupProfile )
