@@ -352,7 +352,7 @@ void KNetworkConf::configureDeviceSlot(){
         //If the interface is wireless, then save the wireless configuration options
         if (dev->getType() == WIRELESS_IFACE_TYPE){
           wifiDev->setEssid(configDlg.extDlg->kleEssid->text());
-          wifiDev->setWepKey(configDlg.extDlg->kleWepKey->text());
+          wifiDev->setWepKey(configDlg.extDlg->kleWepKey->password());
           wifiDev->setKeyType(configDlg.extDlg->qcbKeyType->currentText());
           dev = wifiDev;          
         }
@@ -824,6 +824,16 @@ void KNetworkConf::makeButtonsResizeable(){
 
 void KNetworkConf::enableInterfaceSlot()
 {
+  if (modified) {
+    if (KMessageBox::warningContinueCancel(this,
+                     i18n("The new configuration has not been saved.\nApply changes?"),
+                     i18n("New Configuration Not Saved"),
+                     KStdGuiItem::apply()) == KMessageBox::Continue)
+      saveInfoSlot();
+    else    
+      return;
+  }
+
   KNetworkInterface *dev = getDeviceInfo(klvCardList->currentItem()->text(0));
   if (dev->isActive())
     changeDeviceState(dev->getDeviceName(),DEVICE_DOWN);
@@ -833,6 +843,16 @@ void KNetworkConf::enableInterfaceSlot()
 
 void KNetworkConf::disableInterfaceSlot()
 {
+  if (modified) {
+    if (KMessageBox::warningContinueCancel(this,
+                     i18n("The new configuration has not been saved.\nApply changes?"),
+                     i18n("New Configuration Not Saved"),
+                     KStdGuiItem::apply()) == KMessageBox::Continue)
+      saveInfoSlot();
+    else    
+      return;
+  }
+
   KNetworkInterface *dev = getDeviceInfo(klvCardList->currentItem()->text(0));
   if (dev->isActive())
     changeDeviceState(dev->getDeviceName(),DEVICE_DOWN);
