@@ -1086,9 +1086,9 @@ void KNetworkConfigParser::showSupportedPlatformsDialogSlot(){
       QPixmap distroImg(locate("data","knetworkconf/pixmaps/debian.png"));
       dialog->klbDistroList->insertItem(distroImg, name);
     }
-    else if (key.contains("mandrake"))
+    else if (key.contains("mandriva"))
     {
-      QPixmap distroImg(locate("data","knetworkconf/pixmaps/mandrake.png"));
+      QPixmap distroImg(locate("data","knetworkconf/pixmaps/mandriva.png"));
       dialog->klbDistroList->insertItem(distroImg, name);
     }
     else if (key.contains("conectiva"))
