@@ -135,7 +135,7 @@ void DEBAPT::updateS()
 
 void DEBAPT::upgradeS()
 {
-  if (kprun->run(env + "apt-get upgrade", "APT upgrade")) {
+  if (kprun->run(env + "apt-get dist-upgrade", "APT upgrade")) {
     if (kprun->exec())
       kpackage->management->collectData(TRUE);
   }
