@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -46,10 +46,10 @@ public:
   virtual bool isType(char *buf, const QString &fname);
 
   void listPackages(QPtrList<packageInfo> *pki);
-  QStringList listInstalls(QStringList packs, bool install);
+  QStringList listInstalls(const QStringList &packs, bool install, bool &cancel);
 
-  QString doUninstall(int uninstallFlags, QString packs, bool &test);
-  QString doInstall(int installFlags, QString packs, bool &test);
+  QString doUninstall(int uninstallFlags, const QString &packs, bool &test);
+  QString doInstall(int installFlags, const QString &packs, bool &test);
   QString install(int installFlags, QPtrList<packageInfo> *p,
 		  bool &test);
 
@@ -64,7 +64,9 @@ public:
   void setMenu(KActionCollection* act, bool enable);
 
   QStringList readApt();
-  void writeApt(QStringList list);
+  QStringList readAptS();
+  QStringList readAptF();
+  void writeApt(const QStringList &list);
 
 private slots:
   void updateS();	
