@@ -33,6 +33,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <sys/utsname.h>
 
 #include <qstringlist.h>
 
@@ -376,9 +377,13 @@ void fbsdInterface::setAvail(LcacheObj *slist) {
     }
   }
 
+    // Try /usr/port/INDEX-<major version> on FreeBSD
+    struct utsname fbsdName;
+    if(uname(&fbsdName) != -1 && !strcmp(fbsdName.sysname, "FreeBSD"))
+    	bsdPortsIndexItem::processFile(this, QString("/usr/ports/INDEX-").append(*fbsdName.release), false, "/usr/ports");
+
     // Try the standard ports tree locations.
     bsdPortsIndexItem::processFile(this, "/usr/ports/INDEX", false, "/usr/ports"); // FreeBSD/OpenBSD
-    bsdPortsIndexItem::processFile(this, "/usr/ports/INDEX-5", false, "/usr/ports"); // FreeBSD/OpenBSD
     bsdPortsIndexItem::processFile(this, "/usr/opt/INDEX", false, "/usr/opt");  // NetBSD
 }
 
