@@ -1,9 +1,29 @@
-/////////////////////////////////////////////////////////////////////////////////
-//      $Id: kpTerm.cpp,v 1.12 2002/09/26 20:43:58 leitner Exp $ 
-//
-// File  : pkgOptions.cpp
-// Author: Toivo Pedaste
-//
+/*
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 
 #include "../config.h"
 
@@ -19,20 +39,20 @@
 //////////////////////////////////////////////////////////////////////////////
 
 kpTerm::kpTerm(kpPty *pt, QWidget * parent,  const char * name ) :
-  QMultiLineEdit(parent,name)
+  QTextEdit(parent,name)
 {
   pty = pt;
   setFont(KGlobalSettings::fixedFont());
-  setMinimumWidth(fontMetrics().maxWidth()*80 +
-        minimumSizeHint().width());
-  setWordWrap(QMultiLineEdit::WidgetWidth);
+  //  setMinimumWidth(fontMetrics().maxWidth()*80 +
+  //      minimumSizeHint().width());
+  setWordWrap(NoWrap);
   setReadOnly(TRUE);
 }
 
 void kpTerm::doConnect()
 {
-  connect(pty, SIGNAL(textIn(QString)), this,
-	  SLOT(textIn(QString)));
+  connect(pty, SIGNAL(textIn(const QString &, bool)), this,
+	  SLOT(textIn(const QString &, bool)));
   connect(pty,SIGNAL(result(QStringList &, int)),
 	  this,SLOT(slotResult(QStringList &, int)));
   connect(this, SIGNAL(keyOut(char)), pty,
@@ -41,19 +61,19 @@ void kpTerm::doConnect()
 
 void kpTerm::doUnconnect()
 {
-  disconnect(pty, SIGNAL(textIn(QString)), this,
-		   SLOT(textIn(QString)));
+  disconnect(pty, SIGNAL(textIn(const QString &, bool)), this,
+		   SLOT(textIn(const QString &, bool)));
   disconnect(pty,SIGNAL(result(QStringList &, int)),
 	  this,SLOT(slotResult(QStringList &, int)));
   disconnect(this, SIGNAL(keyOut(char)), pty,
 		   SLOT(keyOut(char)));
 }
 
-bool kpTerm::run(QString cmd, QStringList &r) 
+bool kpTerm::run(const QString &cmd, QStringList &r) 
 {
   setReadOnly(FALSE);
   setFocus();
-  if (pty->start(TRUE)) {
+  if (pty->startSession(TRUE)) {
     doConnect();
 
     r =  pty->run(cmd,FALSE);
@@ -81,18 +101,16 @@ void kpTerm::keyPressEvent ( QKeyEvent * e )
   if (e->ascii()) {
     emit keyOut(e->ascii());
   } else {
-      QMultiLineEdit::keyPressEvent (e);
+      QTextEdit::keyPressEvent (e);
   }
   setCursorPosition(9999,9999);
 }
 
-void kpTerm::textIn(QString stext)
+void kpTerm::textIn(const QString &stext, bool bNewLine)
 {
   QRegExp chrs("[\\010\\012\\015]");
-  //QRegExp chrs("[ed]");
   QString del = "\010";
-  //  kdDebug() << "Tin=[" << stext << "]\n";
-  //  int x,y;
+  // kdDebug() << "Tin=[" << stext << "]\n";
   if (stext.find(chrs) < 0) {
     insert( stext );
   } else {
@@ -100,22 +118,27 @@ void kpTerm::textIn(QString stext)
     int op = 0;
 
     while ((p = stext.find(chrs,op)) >= 0) {
-      if (p != op)
-	insert( stext.mid(op, p-op)); 
+      if (p != op) {
+	insert( stext.mid(op, p-op));
+      }
       if (stext[p] == '\b') {
-	backspace();
+	doKeyboardAction(ActionBackspace);
       } else if (stext[p] == '\r') {
-	home();
+	 moveCursor(MoveLineStart, false);
       }  else if (stext[p] == '\n') {
-	end();
-	newLine();
+	moveCursor(MoveEnd, false);
+	doKeyboardAction(ActionReturn);
       }
       op = p + 1;
     }
     if ((signed int)stext.length() > op)
       insert( stext.right(stext.length()-op));
   }
-  setCursorPosition(9999,9999);
+  if (bNewLine) {
+   	moveCursor(MoveEnd, false);
+	doKeyboardAction(ActionReturn);
+  }
+  moveCursor(MoveEnd, false);
 }
 
 void kpTerm::insert ( const QString & str, bool) {
@@ -125,11 +148,11 @@ void kpTerm::insert ( const QString & str, bool) {
   if (str.length() > 0) {
     //    kdDebug() << "ins:"  << y << "," << x << str <<":" << str.length() << "\n";
     if (x == 0 && str != "\n") {
-      killLine();
+      doKeyboardAction(ActionKill);
       getCursorPosition(&y,&x);
       //      kdDebug() << "k="  << y << "," << x <<"\n";
     }
-    QMultiLineEdit::insert(str,(bool)FALSE);
+    QTextEdit::insert(str,(bool)FALSE);
   }
 }
 
@@ -140,9 +163,11 @@ void kpTerm::slotResult(QStringList &rlist, int ret)
 }
 
 
-//////////////////////////////////////////////////////////////////////////////
-//////////////////////////////////////////////////////////////////////////////
 
+//////////////////////////////////////////////////////////////////////////////
+//
+// Dialog window for password prompt
+//
 //////////////////////////////////////////////////////////////////////////////
 kpRun::kpRun( QWidget *parent)
   :  KDialogBase(parent, "kpRun", true, QString::null,
@@ -156,7 +181,7 @@ kpRun::kpRun( QWidget *parent)
   title->setFont(f);
 
   term = new kpTerm(kpty,page);
-
+  resize(600, 300);
   connect(term,SIGNAL(result(QStringList &, int)),
 	  this,SLOT(slotResult(QStringList &, int)));
  
@@ -178,11 +203,13 @@ bool kpRun::run(QString cmd, QString msg)
   }
 }
 
-void kpRun::addText(QStringList ret)
+void kpRun::addText(const QStringList &ret)
 {
-  for ( QStringList::Iterator it = ret.begin(); it != ret.end(); ++it ) {
+  int last = ret.count()-1;
+  int i = 0;
+  for ( QStringList::ConstIterator it = ret.begin(); it != ret.end(); ++it, ++i ) {
     //    kdDebug() << "ks=" << *it << "\n";
-    term->textIn(*it);
+    term->textIn(*it, (i != last));
   }
 }
 
