@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -98,9 +98,9 @@ public:
   void packageHighlighted(QListViewItem *item, packageDisplayWidget *packageDisplay);
   // A package has been highlighted in the list tree
 
-  KpTreeListItem *search(QString str, QString head,
+  KpTreeListItem *search(const QString &str, const QString &head,
 			KpTreeListItem  *start = 0);
-  KpTreeListItem *search(QString str, bool subStr, bool wrap, bool start);
+  KpTreeListItem *search(const QString &str, bool subStr, bool wrap, bool start);
   // search for a package in tree
   KpTreeListItem *changePack(KpTreeListItem *searchResult, bool push = true);
   // Change to other package
@@ -112,8 +112,8 @@ public:
   void writeTreeType();
   // config: Tree display type
 
-  void writeTreePos();
-  void readTreePos();
+  void writeTreeConfig();
+  void readTreeConfig();
   // save and restore column positions
 
  int treeType;
