@@ -447,6 +447,7 @@ void managementWidget::installSingleClicked()
   }
   kpackage->setPercent(100);
 
+  searchLine->updateSearch();
   checkMarked();
 }
 
@@ -494,6 +495,7 @@ void managementWidget::installMultClicked()
   }
   delete [] lst;
 
+  searchLine->updateSearch();
   checkMarked();
 }
 
@@ -534,6 +536,7 @@ void managementWidget::uninstallSingleClicked()
   }
   kpackage->setPercent(100);
 
+  searchLine->updateSearch();
   checkMarked();
 }
 
@@ -579,6 +582,7 @@ void managementWidget::uninstallMultClicked()
   }
   delete [] lst;
 
+  searchLine->updateSearch();
   checkMarked();
 }
 
@@ -645,8 +649,6 @@ KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool install)
 	if (!q) {
 	  printf("NOTP=%s \n",pnew->getProperty("name").ascii());
 	} else {
-	  treeList->sweep(true);
-	  searchLine->updateSearch();
 	  return q;
 	}
       }
@@ -670,8 +672,6 @@ KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool install)
 	  if (!q) {
 	    printf("NOTP=%s \n",pb->getProperty("name").ascii());
 	  } else {
-	    treeList->sweep(true);
-	    searchLine->updateSearch();
 	    return q;
 	  }
 	}
@@ -681,8 +681,6 @@ KpTreeListItem *managementWidget::updatePackage(packageInfo *pki, bool install)
       }
     }
   }
-  treeList->sweep(true);
-  searchLine->updateSearch();
 
   return 0;
 }
