@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -285,8 +285,8 @@ void updateLoc::doBase(const QString & bmsg)
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-aUpdateLoc::aUpdateLoc(QWidget *p, int panelNumber, pkgInterface *inter, QString iname,
-			 int numberLines, QString label)
+aUpdateLoc::aUpdateLoc(QWidget *p, int panelNumber, pkgInterface *inter, const QString &iname,
+			 int numberLines, const QString &label)
   : updateLoc(p, panelNumber, inter, iname)
 {
 
@@ -362,15 +362,8 @@ void aUpdateLoc::writeSettings() {
       if (ap[i]->getUse()) {
 	s = "";
       } else {
-	s = "\\# ";
+	s = "# ";
       }
-      ln.replace("#","\\#");
-      ln.replace(">","\\>");
-      ln.replace("<","\\<");
-      ln.replace(";","\\;");
-      ln.replace("'","''");
-      ln.replace("`","``");
-      ln.replace("\"","\"\"");
       s += ln;
       list.append(s);
     }
