@@ -22,7 +22,7 @@
 #include "Properties.h"
 
 KSVServicePropertiesDialog::KSVServicePropertiesDialog (KSVData& data, QWidget* parent)
-  : KPropertiesDialog (data.filenameAndPath(), (mode_t)-1,
+  : KPropertiesDialog (KURL(data.filenameAndPath()),
                        parent, "KSVServicePropertiesDialog", true, false),
   mData (data)
 {
