@@ -1,6 +1,4 @@
 /***************************************************************************
-                          TopWidget.h  -  description
-                             -------------------
     begin                : Sun Oct 3 1999
     copyright            : (C) 1997-99 by Peter Putzer
     email                : putzer@kde.org
@@ -49,7 +47,7 @@ public:
 public slots:
   void setCaption (bool changed);
 
-private:
+protected:
   virtual bool queryExit();
   virtual void closeEvent( QCloseEvent* e );
   void initTools();
