@@ -11,9 +11,10 @@ int KSVApplication::newInstance ()
   QWidget* main = mainWidget();
 
   if (main)
-    KWin::setActiveWindow (main->winId());
+    KWin::activateWindow (main->winId());
 
   return getpid();
 }
 
 #include "ksvapplication.moc"
+
