@@ -12,8 +12,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 
@@ -28,7 +28,7 @@
 class delUser: public KDialogBase {
   Q_OBJECT
 public:
-  delUser(KUser *AUser, QWidget *parent = 0, const char *name = 0);
+  delUser(KU::KUser *AUser, QWidget *parent = 0, const char *name = 0);
 
   bool getDeleteHomeDir()
      { return m_deleteHomeDir->isChecked(); }
