@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 
@@ -35,7 +35,7 @@ class editGroup : public KDialogBase
   Q_OBJECT
 public:
 
-  editGroup(KGroup *akg, bool samba, bool add, 
+  editGroup(KU::KGroup *akg, bool samba, bool add, 
     QWidget* parent = NULL, const char* name = NULL);
 
   virtual ~editGroup();
@@ -49,7 +49,7 @@ protected slots:
 private:
   bool mSamba, mAdd;
   bool ro;
-  KGroup *kg;
+  KU::KGroup *kg;
   KListView *m_list_in,*m_list_notin;
   KLineEdit   *legrpname;
   KLineEdit   *legid;
