@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef _KU_GLOBAL_H_
@@ -32,13 +32,13 @@ public:
   void initCfg( const QString &connection );
   
   KUserPrefsBase *kcfg() { return cfg; }
-  KUsers &getUsers();
-  KGroups &getGroups();
+  KU::KUsers &getUsers();
+  KU::KGroups &getGroups();
   
 private:
 
-  KUsers *users;
-  KGroups *groups;
+  KU::KUsers *users;
+  KU::KGroups *groups;
   
   KUserPrefsBase *cfg;
 };
