@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef _KU_GROUPVW_H_
@@ -30,13 +30,13 @@
 class KGroupViewItem : public KListViewItem
 {
 public:
-  KGroupViewItem(KListView *parent, KGroup *aku);
-  KGroup *group() { return mGroup; }
+  KGroupViewItem(KListView *parent, KU::KGroup *aku);
+  KU::KGroup *group() { return mGroup; }
 private:  
   virtual QString text ( int ) const;
   virtual int compare( QListViewItem *i, int col, bool ascending ) const;
   
-  KGroup *mGroup;
+  KU::KGroup *mGroup;
 };
 
 class KGroupView : public KListView
@@ -48,9 +48,9 @@ public:
 
   virtual ~KGroupView();
 
-  void insertItem(KGroup *aku);
-  void removeItem(KGroup *aku);
-  KGroup *getCurrentGroup();
+  void insertItem(KU::KGroup *aku);
+  void removeItem(KU::KGroup *aku);
+  KU::KGroup *getCurrentGroup();
   void init();
 };
 
