@@ -12,8 +12,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef _KUSERLDAP_H_
@@ -32,7 +32,7 @@
 
 #include "kuser.h"
 
-class KUserLDAP : public QObject, public KUsers {
+class KUserLDAP : public QObject, public KU::KUsers {
 Q_OBJECT
 public:
   KUserLDAP(KUserPrefsBase *cfg);
@@ -50,18 +50,18 @@ private:
   KABC::LDAPUrl mUrl;
   KProgressDialog *mProg;
   bool mOk, mCancel;
-  KUser *mUser, *mDelUser, *mAddUser;
+  KU::KUser *mUser, *mDelUser, *mAddUser;
   int mAdv;
   QCString ldif;
+  int schemaversion;
+  QStringList mOc;
+  QMap<KU::KUser*, QStringList> mObjectClasses;
   
-  QString getRDN( KUser *user );
-  void getLDIF( KUser *user, bool mod );
-  void delData( KUser *user );
-  
-  virtual void createPassword( KUser *user, const QString &password );
-  
+  QString getRDN( KU::KUser *user );
+  void getLDIF( KU::KUser *user, bool mod );
+  void delData( KU::KUser *user );
   
+  virtual void createPassword( KU::KUser *user, const QString &password );
 };
 
-#endif // _KUSER_H_
-
+#endif // _KUSERLDAP_H_
