@@ -14,12 +14,12 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
-#ifndef _KUSERSYSTEM_H_
-#define _KUSERSYSTEM_H_
+#ifndef _KU_USERSYSTEM_H_
+#define _KU_USERSYSTEM_H_
 
 #include <sys/types.h>
 
@@ -28,19 +28,19 @@
 
 #include "kuser.h"
 
-class KUserSystem : public KUsers {
+class KUserSystem : public KU::KUsers {
 public:
   KUserSystem(KUserPrefsBase *cfg);
   virtual ~KUserSystem();
 
   virtual bool dbcommit() { return true; }
   virtual bool reload();
-  virtual void createPassword( KUser * /*user*/, const QString & /*password*/ ) {}
+  virtual void createPassword( KU::KUser * /*user*/, const QString & /*password*/ ) {}
 
 private:
 
   bool loadpwd();
   bool loadsdw();
 };
-#endif // _KUSER_H_
+#endif // _KU_USERSYSTEM_H_
 
