@@ -14,12 +14,12 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
-#ifndef _KU_MAINWIDGET_H
-#define _KU_MAINWIDGET_H
+#ifndef _KU_MAINWIDGET_H_
+#define _KU_MAINWIDGET_H_
 
 #include <kmainwindow.h>
 
@@ -44,6 +44,7 @@ protected slots:
   void slotApplySettings();
   void slotApplyConnection();
   void selectconn();
+  void reload();
 
 private:
   KToggleAction *mShowSys;
@@ -52,4 +53,4 @@ private:
 
 };
 
-#endif // _KU_MAINWIDGET_H
+#endif // _KU_MAINWIDGET_H_
